import os

DB = [
    ('amelia', 'about to kiss,jess,jimmy,photo booth', 'IMG_1260'),
    ('amelia', 'adriane,jesse,kodak moment,photo booth', 'IMG_1273'),
    ('amelia', 'amelia,leif,photo booth,setup', 'IMG_1230'),
    ('amelia', 'american gothic,grace,mustache,photo booth,wingo', 'IMG_1280'),
    ('amelia', 'andrew,bee\'s knees,liz,photo booth', 'IMG_1268'),
    ('amelia', 'andrew,bee\'s knees,liz,photo booth', 'IMG_1270'),
    ('amelia', 'andrew,hats,liz,photo booth', 'IMG_1269'),
    ('amelia', 'andrew,liz', 'IMG_1267'),
    ('amelia', 'andy,lisa,photo booth', 'IMG_1255'),
    ('amelia', 'andy,lisa,photo booth', 'IMG_1256'),
    ('amelia', 'andy,lisa,photo booth', 'IMG_1257'),
    ('amelia', 'awesome,grace,photo booth,silly,wingo', 'IMG_1279'),
    ('amelia', 'bink,photo booth', 'IMG_1236'),
    ('amelia', 'blue shirts,glamour shots,jon,photo booth,silly,wingo', 'IMG_1284'),
    ('amelia', 'blue shirts,glamour shots,jon,photo booth,slideshow,wingo', 'IMG_1286'),
    ('amelia', 'blue shirts,jon,mustache,photo booth,silly,wingo', 'IMG_1289'),
    ('amelia', 'blue shirts,jon,photo booth,silly,wingo', 'IMG_1283'),
    ('amelia', 'blue shirts,jon,photo booth,silly,wingo', 'IMG_1288'),
    ('amelia', 'carlie,hats,klayton,photo booth', 'IMG_1251'),
    ('amelia', 'carlie,kiss,klayton,photo booth,slideshow', 'IMG_1253'),
    ('amelia', 'carlie,klayton,photo booth', 'IMG_1252'),
    ('amelia', 'carlie,klayton,photo booth', 'IMG_1254'),
    ('amelia', 'corinne,millie', 'IMG_1235'),
    ('amelia', 'david,glasses,jesse,photo booth', 'IMG_1275'),
    ('amelia', 'eric,kiss,nancy,photo booth', 'IMG_1248'),
    ('amelia', 'eric,nancy,photo booth', 'IMG_1247'),
    ('amelia', 'flowers,hats,john,setup', 'IMG_1296'),
    ('amelia', 'flowers,setup', 'IMG_1292'),
    ('amelia', 'glasses,liza', 'IMG_1240'),
    ('amelia', 'glasses,liza,photo booth', 'IMG_1245'),
    ('amelia', 'grace,photo booth,wingo', 'IMG_1277'),
    ('amelia', 'grace,photo booth,wingo', 'IMG_1278'),
    ('amelia', 'jail,jon', 'IMG_1250'),
    ('amelia', 'jason,photo booth,zane', 'IMG_1238'),
    ('amelia', 'jess,jimmy,kiss,photo booth', 'IMG_1261'),
    ('amelia', 'jess,jimmy,photo booth', 'IMG_1258'),
    ('amelia', 'jess,laughs,liz,photo booth', 'IMG_1266'),
    ('amelia', 'jess,liz,photo booth', 'IMG_1264'),
    ('amelia', 'jess,liz,photo booth', 'IMG_1265'),
    ('amelia', 'jesse,photo booth,valen', 'IMG_1291'),
    ('amelia', 'joanie,michael,photo booth', 'IMG_1239'),
    ('amelia', 'joff,photo booth,silly,slideshow', 'IMG_1237'),
    ('amelia', 'jon,photo booth,silly', 'IMG_1290'),
    ('amelia', 'klayton,photo booth', 'IMG_1249'),
    ('amelia', 'nancy,photo booth', 'IMG_1246'),
    ('amelia', 'newton,photo booth', 'IMG_1241'),
    ('amelia', 'slideshow,flowers,setup', 'IMG_1293'),
    ('bobbie', '', 'DSC07807'),
    ('bobbie', 'amelia,ceremony,jesse,lily,slideshow', 'DSC07827'),
    ('bobbie', 'amelia,champagne,jesse,john', 'DSC07868'),
    ('bobbie', 'amelia,jesse,leif,lily,paparazzi,valen', 'DSC08018'),
    ('bobbie', 'amelia,jesse,leif,lily,where\'s soren', 'DSC08017'),
    ('bobbie', 'andrea,bink,eric,john,leif,lily,nancy,parents,susan', 'DSC07989'),
    ('bobbie', 'andrea,bink,eric,john,leif,lily,nancy,parents,susan', 'DSC07991'),
    ('bobbie', 'andrea,bink,eric,john,leif,lily,nancy,susan', 'DSC07987'),
    ('bobbie', 'andrea,bink,eric,john,leif,lily,nancy,susan', 'DSC07988'),
    ('bobbie', 'andrea,bink,john,susan', 'DSC08001'),
    ('bobbie', 'andrea,dancing,john', 'DSC07941'),
    ('bobbie', 'andrea,dancing,john,leif,lily', 'DSC07939'),
    ('bobbie', 'andrea,dancing,john,lily', 'DSC07940'),
    ('bobbie', 'andrea,dancing,leif', 'DSC07943'),
    ('bobbie', 'andrea,dancing,leif', 'DSC07945'),
    ('bobbie', 'andrea,dancing,leif', 'DSC07946'),
    ('bobbie', 'andrea,dunes,john,susan', 'DSC08005'),
    ('bobbie', 'andrea,john', 'DSC08006'),
    ('bobbie', 'andrea,john', 'DSC08007'),
    ('bobbie', 'andrea,john,leif,lily', 'DSC07983'),
    ('bobbie', 'andrea,john,leif,lily', 'DSC07984'),
    ('bobbie', 'andrea,john,leif,lily', 'DSC07986'),
    ('bobbie', 'andrea,john,lunch', 'DSC07894'),
    ('bobbie', 'band,dancing', 'DSC07925'),
    ('bobbie', 'bink,champagne,eric,nancy,parents,susan', 'DSC07862'),
    ('bobbie', 'bink,champagne,eric,nancy,parents,susan', 'DSC07863'),
    ('bobbie', 'bink,champagne,eric,nancy,susan', 'DSC07861'),
    ('bobbie', 'bink,champagne,soren,susan', 'DSC07865'),
    ('bobbie', 'bink,dress,leif,lily,susan', 'DSC08002'),
    ('bobbie', 'bink,dunes,eric,peter,susan', 'DSC07829'),
    ('bobbie', 'bink,leif,lily,susan', 'DSC08004'),
    ('bobbie', 'bink,tim', 'DSC07952'),
    ('bobbie', 'bink,tim', 'DSC07967'),
    ('bobbie', 'bobbie,carlie,eric,klayton,louise,nancy,nell,soren,thor', 'DSC07798'),
    ('bobbie', 'bobbie,glasses,klayton', 'DSC07817'),
    ('bobbie', 'bobbie,klayton', 'DSC07820'),
    ('bobbie', 'bobbie,klayton', 'DSC07821'),
    ('bobbie', 'bobbie,klayton,thor', 'DSC07898'),
    ('bobbie', 'bobbie,klayton,thor', 'DSC07912'),
    ('bobbie', 'bobbie,klayton,thor', 'DSC07914'),
    ('bobbie', 'carlie,eric,klayton,louise,ocean,slideshow,soren', 'DSC08034'),
    ('bobbie', 'carlie,hats', 'DSC07928'),
    ('bobbie', 'carlie,klayton,louise', 'DSC08027'),
    ('bobbie', 'carlie,klayton,louise', 'DSC08031'),
    ('bobbie', 'carlie,klayton,louise', 'DSC08032'),
    ('bobbie', 'ceremony', 'DSC07832'),
    ('bobbie', 'ceremony', 'DSC07838'),
    ('bobbie', 'ceremony', 'DSC07839'),
    ('bobbie', 'ceremony', 'DSC07845'),
    ('bobbie', 'ceremony', 'DSC07846'),
    ('bobbie', 'ceremony', 'DSC07847'),
    ('bobbie', 'ceremony', 'DSC07851'),
    ('bobbie', 'ceremony', 'DSC07854'),
    ('bobbie', 'ceremony', 'DSC07856'),
    ('bobbie', 'ceremony,husband and wife,leif,lily,peter,soren', 'DSC07859'),
    ('bobbie', 'ceremony,kiss,slideshow', 'DSC07858'),
    ('bobbie', 'ceremony,leif,peter,soren', 'DSC07833'),
    ('bobbie', 'ceremony,vows', 'DSC07853'),
    ('bobbie', 'champagne,conch,lisa,peter', 'DSC07869'),
    ('bobbie', 'champagne,jesse,john', 'DSC07867'),
    ('bobbie', 'dancing', 'DSC07926'),
    ('bobbie', 'dancing', 'DSC07969'),
    ('bobbie', 'dancing', 'DSC07970'),
    ('bobbie', 'dancing,john,lily', 'DSC07929'),
    ('bobbie', 'dancing,john,lily', 'DSC07930'),
    ('bobbie', 'dancing,john,lily', 'DSC07931'),
    ('bobbie', 'dancing,leif,lily', 'DSC07932'),
    ('bobbie', 'dancing,leif,lily', 'DSC07933'),
    ('bobbie', 'dancing,leif,lily', 'DSC07934'),
    ('bobbie', 'dancing,leif,lily', 'DSC07935'),
    ('bobbie', 'dancing,leif,lily', 'DSC07942'),
    ('bobbie', 'debbie', 'DSC08036'),
    ('bobbie', 'decor', 'DSC07822'),
    ('bobbie', 'decor,dunes', 'DSC07812'),
    ('bobbie', 'dunes', 'DSC07809'),
    ('bobbie', 'dunes', 'DSC07965'),
    ('bobbie', 'dunes,jason,robin', 'DSC07973'),
    ('bobbie', 'eric,glasses,nancy,soren', 'DSC07972'),
    ('bobbie', 'eric,hats,leif,lily,nancy', 'DSC07998'),
    ('bobbie', 'eric,hats,lunch,nancy', 'DSC07886'),
    ('bobbie', 'eric,leif,lily,nancy', 'DSC07999'),
    ('bobbie', 'eric,louise,max,nell,thor', 'DSC08025'),
    ('bobbie', 'eric,lunch,susan,toast', 'DSC07903'),
    ('bobbie', 'eric,susan,toast', 'DSC07905'),
    ('bobbie', 'eric,toast', 'DSC07919'),
    ('bobbie', 'flags,jason,joff,robin,zane', 'DSC07951'),
    ('bobbie', 'glasses,hats,leif,lily,lunch,silly', 'DSC07891'),
    ('bobbie', 'glasses,soren,slideshow', 'DSC07971'),
    ('bobbie', 'kiss,leif,lily,slideshow', 'DSC08009'),
    ('bobbie', 'klayton', 'DSC07813'),
    ('bobbie', 'klayton,louise', 'DSC08026'),
    ('bobbie', 'klayton,louise,nell,thor', 'DSC07825'),
    ('bobbie', 'klayton,thor', 'DSC07909'),
    ('bobbie', 'leif,lily', 'DSC08011'),
    ('bobbie', 'leif,lily', 'DSC08013'),
    ('bobbie', 'leif,lily', 'DSC08016'),
    ('bobbie', 'leif,lily,peter', 'DSC07994'),
    ('bobbie', 'leif,lunch,toast', 'DSC07923'),
    ('bobbie', 'leif,toast', 'DSC07922'),
    ('bobbie', 'lisa,peter', 'DSC07875'),
    ('bobbie', 'lisa,peter', 'DSC07876'),
    ('bobbie', 'louise,pig tails,soren', 'DSC07806'),
    ('bobbie', 'lunch', 'DSC07877'),
    ('bobbie', 'lunch', 'DSC07878'),
    ('bobbie', 'lunch', 'DSC07879'),
    ('bobbie', 'lunch', 'DSC07880'),
    ('bobbie', 'lunch', 'DSC07882'),
    ('bobbie', 'lunch', 'DSC07890'),
    ('bobbie', 'lunch', 'DSC07897'),
    ('bobbie', 'lunch', 'DSC07906'),
    ('bobbie', 'lunch,max,nansamba', 'DSC07896'),
    ('bobbie', 'lunch,slideshow', 'DSC07889'),
    ('bobbie', 'nell,soren,thor', 'DSC07803'),
    ('bobbie', 'paparazzi', 'DSC08020'),
    ('bobbie', 'paparazzi', 'DSC08021'),
    ('bobbie', 'paparazzi', 'DSC08022'),
    ('bobbie', 'paparazzi', 'DSC08023'),
    ('bobbie', 'pete,tim', 'DSC07826'),
    ('bobbie', 'slideshow,amelia,amy,laura,lily', 'DSC08038'),
    ('bobbie', 'slideshow,leif,lily', 'DSC08012'),
    ('bobbie', 'soren,toast', 'DSC07918'),
    ('debbie', 'amelia,andrea,debbie,friday,tori', 'IMG_4970'),
    ('debbie', 'amelia,andrea,dunes,slideshow', 'IMG_5035'),
    ('debbie', 'amelia,ceremony,jesse', 'IMG_4995'),
    ('debbie', 'amelia,ceremony,jesse,lily,nancy,peter', 'IMG_4998 - Version 2'),
    ('debbie', 'amelia,toast', 'IMG_5018'),
    ('debbie', 'amy,john', 'IMG_5003'),
    ('debbie', 'andrea', 'IMG_4992'),
    ('debbie', 'andrea', 'IMG_5020'),
    ('debbie', 'andrea,cuy,john', 'IMG_4990'),
    ('debbie', 'andrea,tori', 'IMG_4991'),
    ('debbie', 'andrew,leif,mormon', 'IMG_4962'),
    ('debbie', 'bobbie', 'IMG_5025'),
    ('debbie', 'carlie,klayton,louise', 'IMG_5033'),
    ('debbie', 'ceremony,dress', 'IMG_5002'),
    ('debbie', 'ceremony,janice,josh,newton,steve', 'IMG_4997'),
    ('debbie', 'cozy', 'IMG_5051'),
    ('debbie', 'cuy,joanie,michael', 'IMG_5023'),
    ('debbie', 'dancing', 'IMG_5024'),
    ('debbie', 'david,friday,john', 'IMG_4965'),
    ('debbie', 'david,glasses,hats,john', 'IMG_5010'),
    ('debbie', 'david,joanie,slideshow', 'IMG_4986'),
    ('debbie', 'dunes', 'IMG_5032'),
    ('debbie', 'eric,susan', 'IMG_4993'),
    ('debbie', 'eric,susan,toast', 'IMG_5017'),
    ('debbie', 'flowers', 'IMG_5028'),
    ('debbie', 'friday,jesse,valen', 'IMG_4972'),
    ('debbie', 'hats,joanie,michael', 'IMG_5026'),
    ('debbie', 'hats,john,laura,slideshow', 'IMG_4983'),
    ('debbie', 'hats,leif,silly', 'IMG_5013'),
    ('debbie', 'joanie,tori', 'IMG_4985'),
    ('debbie', 'john', 'IMG_5016'),
    ('debbie', 'john,lily,ring', 'IMG_5012'),
    ('debbie', 'john,toast', 'IMG_5015'),
    ('debbie', 'leif,lily,nansamba,peter,sunset,susan', 'IMG_5052'),
    ('debbie', 'leif,lily,slideshow,toes', 'IMG_5007'),
    ('debbie', 'lily,shay', 'IMG_5014'),
    ('debbie', 'lisa', 'IMG_5009'),
    ('debbie', 'louise', 'IMG_4969'),
    ('debbie', 'lunch', 'IMG_5011'),
    ('debbie', 'moon,slideshow', 'IMG_5047'),
    ('debbie', 'peter,tori', 'IMG_4988'),
    ('debbie', 'slideshow', 'IMG_5042'),
    ('debbie', 'slideshow,amy,tori', 'IMG_5029'),
    ('debbie', 'slideshow,andrea,ceremony,john', 'IMG_4996'),
    ('debbie', 'slideshow,ceremony,leif,lily,peter', 'IMG_4999'),
    ('debbie', 'slideshow,ceremony,leif,lily,secret', 'IMG_5000 - Version 3'),
    ('debbie', 'slideshow,ceremony,leif,lily,secret', 'IMG_5001 - Version 3'),
    ('debbie', 'slideshow,ceremony,lily,peter', 'IMG_4994'),
    ('debbie', 'slideshow,flowers', 'IMG_5005'),
    ('debbie', 'slideshow,glasses,hats,leif', 'IMG_5022 - Version 2'),
    ('debbie', 'slideshow,lunch', 'IMG_5004'),
    ('debbie', 'sunset', 'IMG_5040'),
    ('debbie', 'sunset', 'IMG_5041'),
    ('debbie', 'sunset,tori', 'IMG_5036'),
    ('debbie', 'the box', 'IMG_4984'),
    ('debbie', 'tori', 'IMG_4989'),
    ('joanie', 'amelia,andrea,ceremony,jesse,john,lily,slideshow', 'P1050121'),
    ('joanie', 'amelia,ceremony,jesse,lily,slideshow', 'P1050114'),
    ('joanie', 'amelia,ceremony,kiss', 'P1050149'),
    ('joanie', 'amelia,ceremony,leif,lily,ring', 'P1050147'),
    ('joanie', 'amelia,ceremony,lily,slideshow', 'P1050123'),
    ('joanie', 'amy,andrea,bink,carlie,ceremony,eric,hannah,janice,josh,klayton,liza,margo,nancy,slideshow,susan,valen', 'P1050131'),
    ('joanie', 'amy,david,joanie', 'P1050112'),
    ('joanie', 'amy,joanie,pgcc,tori', 'P1050101'),
    ('joanie', 'andrea,carlie,ceremony,john,margo,valen', 'P1050125'),
    ('joanie', 'andrea,ceremony,grace,john,margo,valen', 'P1050126'),
    ('joanie', 'andrea,john,lunch', 'P1050174'),
    ('joanie', 'andy,jan,lisa', 'P1050217'),
    ('joanie', 'andy,lisa', 'P1050192'),
    ('joanie', 'band,dancing', 'P1050197'),
    ('joanie', 'bink,ceremony,eric,susan', 'P1050132'),
    ('joanie', 'bink,ceremony,leif,nancy,slideshow,soren,susan', 'P1050115'),
    ('joanie', 'ceremony', 'P1050140'),
    ('joanie', 'ceremony,david,joanie,kirsten,laura,nansamba,wingo', 'P1050130'),
    ('joanie', 'ceremony,jesse,leif,lily,peter', 'P1050137'),
    ('joanie', 'ceremony,jesse,leif,lily,peter,soren', 'P1050135'),
    ('joanie', 'ceremony,leif,soren,slideshow', 'P1050110'),
    ('joanie', 'ceremony,slideshow', 'P1050133'),
    ('joanie', 'champagne,david,joanie,kirsten,tim', 'P1050157'),
    ('joanie', 'cuy,flags,slideshow', 'P1050222'),
    ('joanie', 'dancing', 'P1050199'),
    ('joanie', 'david', 'P1050109'),
    ('joanie', 'david,glasses,hats,john,lunch', 'P1050177'),
    ('joanie', 'david,hats,joanie', 'P1050106'),
    ('joanie', 'david,joanie', 'P1050200'),
    ('joanie', 'david,joanie,laura,nansamba', 'P1050129'),
    ('joanie', 'david,lunch', 'P1050163'),
    ('joanie', 'debbie', 'P1050103'),
    ('joanie', 'debbie', 'P1050104'),
    ('joanie', 'dunes', 'P1050107'),
    ('joanie', 'dunes', 'P1050153'),
    ('joanie', 'dunes,slideshow', 'P1050138'),
    ('joanie', 'glasses,john', 'P1050173'),
    ('joanie', 'hats', 'P1050102'),
    ('joanie', 'hats,joanie', 'P1050216'),
    ('joanie', 'hats,leif', 'P1050190'),
    ('joanie', 'hats,leif,lunch', 'P1050179'),
    ('joanie', 'joanie', 'P1050094'),
    ('joanie', 'joanie', 'P1050097'),
    ('joanie', 'joanie,leif', 'P1050161'),
    ('joanie', 'leif', 'P1050178'),
    ('joanie', 'leif,lily', 'P1050156'),
    ('joanie', 'leif,lily', 'P1050189'),
    ('joanie', 'leif,lily,susan', 'P1050182'),
    ('joanie', 'lily', 'P1050145'),
    ('joanie', 'lily', 'P1050185'),
    ('joanie', 'lunch,pgcc', 'P1050180'),
    ('joanie', 'lunch,slideshow', 'P1050162'),
    ('joanie', 'slideshow,adriane,amy,david,joanie,tim', 'P1050139'),
    ('joanie', 'slideshow,amelia,andrea,ceremony,jesse,john,lily', 'P1050120'),
    ('joff', 'about to kiss,ceremony,leif,lily,peter', '100_1572'),
    ('joff', 'amelia,jesse,lily,rehearsal', '100_1455'),
    ('joff', 'amelia,rehearsal', '100_1469'),
    ('joff', 'andrea,john,laughs,leif,rehearsal,soren,slideshow', '100_1450'),
    ('joff', 'andrea,setup,susan', '100_1506'),
    ('joff', 'bink,setup', '100_1488'),
    ('joff', 'bink,setup,valen', '100_1492'),
    ('joff', 'carolyn,dunes,jim', '100_1589'),
    ('joff', 'carolyn,susan,slideshow', '100_1593'),
    ('joff', 'cass,champagne,cuy,dunes,pete,shay,tim', '100_1581'),
    ('joff', 'ceremony,dunes,slideshow', '100_1558'),
    ('joff', 'ceremony,leif,lily,peter', '100_1573'),
    ('joff', 'ceremony,leif,lily,peter,ring', '100_1570'),
    ('joff', 'ceremony,leif,lily,peter,slideshow', '100_1566'),
    ('joff', 'ceremony,leif,soren', '100_1568'),
    ('joff', 'ceremony,ring,slideshow', '100_1571'),
    ('joff', 'champagne', '100_1582'),
    ('joff', 'champagne,dunes', '100_1583'),
    ('joff', 'champagne,eric,robin,zane', '100_1588'),
    ('joff', 'conch,hats,lily,peter,rehearsal', '100_1451'),
    ('joff', 'dancing', '100_1602'),
    ('joff', 'dancing,max,nansamba', '100_1605'),
    ('joff', 'devin,jason,melissa,nell,thor', '100_1580'),
    ('joff', 'dunes,leif,lily,peter,rehearsal', '100_1481'),
    ('joff', 'dunes,rehearsal,slideshow', '100_1438'),
    ('joff', 'dunes,slideshow', '100_1542'),
    ('joff', 'eric,laughs,nancy,rehearsal,slideshow', '100_1441'),
    ('joff', 'eric,nancy,thor', '100_1548'),
    ('joff', 'flags', '100_1604'),
    ('joff', 'flags,hats,zane', '100_1601'),
    ('joff', 'flowers,slideshow', '100_1534'),
    ('joff', 'glasses,john,valen', '100_1606'),
    ('joff', 'grace,homies,jon,leif,lily,setup,wingo', '100_1531'),
    ('joff', 'hands on hips,lunch,pgcc', '100_1595'),
    ('joff', 'hats,leif,lily,peter,rehearsal,silly', '100_1442'),
    ('joff', 'hats,peter,rehearsal', '100_1470'),
    ('joff', 'jesse,rehearsal,slideshow', '100_1480'),
    ('joff', 'john,rehearsal,susan', '100_1440'),
    ('joff', 'klayton,nell,thor', '100_1550'),
    ('joff', 'laughs,leif,rehearsal,soren', '100_1448'),
    ('joff', 'leif,lily,slideshow', '100_1576'),
    ('joff', 'lily,rehearsal', '100_1460'),
    ('joff', 'louise,nancy,nell,thor', '100_1553'),
    ('joff', 'louise,slideshow', '100_1584'),
    ('joff', 'meta,rehearsal', '100_1445'),
    ('joff', 'milling about', '100_1546'),
    ('joff', 'nell,thor', '100_1594'),
    ('joff', 'pgcc,setup', '100_1547'),
    ('joff', 'rehearsal', '100_1436'),
    ('joff', 'slideshow', '100_1539'),
    ('joff', 'slideshow,dunes', '100_1607'),
    ('jon', '', 'DSCF0827'),
    ('jon', '', 'DSCF0874'),
    ('jon', 'about to kiss,eric,klayton,meta,nancy,photo booth', 'DSCF0915'),
    ('jon', 'amelia', 'DSCF0805'),
    ('jon', 'amelia,andrea,jesse,john,leif,lily', 'DSCF0954'),
    ('jon', 'amelia,ceremony,jesse,lily,slideshow', 'DSCF0852'),
    ('jon', 'amelia,ceremony,leif,lily,peter', 'DSCF0855'),
    ('jon', 'american gothic,dress,leif,lily,toes', 'DSCF0957'),
    ('jon', 'amy,blue shirts,lily,lunch,slideshow', 'DSCF0864'),
    ('jon', 'andrea,bink,ceremony,john,susan', 'DSCF0850'),
    ('jon', 'andrea,dunes,glasses,hats,leif,milling about,nancy', 'DSCF0905'),
    ('jon', 'andrea,josh,omg,tim', 'DSCF0910'),
    ('jon', 'andrew,bee\'s knees,eve,hats,liz', 'DSCF0934'),
    ('jon', 'andrew,blue shirts,hats,mormon,wingo', 'DSCF0923'),
    ('jon', 'andrew,dunes,grace,kirsten,mormon,pete,wingo', 'DSCF0983'),
    ('jon', 'andrew,eve,hats,liz', 'DSCF0950'),
    ('jon', 'andrew,glasses,grace,jon,meta,mormon', 'DSCF0994'),
    ('jon', 'andrew,lunch,mormon', 'DSCF0867'),
    ('jon', 'andrew,mormon,wingo', 'DSCF0817'),
    ('jon', 'andy,lisa', 'DSCF0919'),
    ('jon', 'beach', 'DSCF0803'),
    ('jon', 'beach', 'DSCF0828'),
    ('jon', 'beach', 'DSCF0981'),
    ('jon', 'bee\'s knees,david', 'DSCF0936'),
    ('jon', 'bee\'s knees,glasses', 'DSCF0933'),
    ('jon', 'bee\'s knees,wingo', 'DSCF0902'),
    ('jon', 'bink,dunes', 'DSCF0927'),
    ('jon', 'bink,leif,lily,susan', 'DSCF0959'),
    ('jon', 'blue shirts,grace,lunch,pete,wingo', 'DSCF0896'),
    ('jon', 'cass,dessert,kirsten,pete,tim', 'DSCF0941'),
    ('jon', 'cass,kirsten,pete,tim', 'DSCF0853'),
    ('jon', 'cass,tim', 'DSCF0990'),
    ('jon', 'champagne,dunes,milling about', 'DSCF0859'),
    ('jon', 'champagne,dunes,slideshow', 'DSCF0857'),
    ('jon', 'corinne,hats,millie', 'DSCF0875'),
    ('jon', 'corinne,millie', 'DSCF0876'),
    ('jon', 'dancing,grace,lily', 'DSCF0922'),
    ('jon', 'decor', 'DSCF0839'),
    ('jon', 'decor', 'DSCF0847'),
    ('jon', 'decor', 'DSCF0877'),
    ('jon', 'dessert', 'DSCF0944'),
    ('jon', 'dress,leif,lily', 'DSCF0958'),
    ('jon', 'dunes', 'DSCF0836'),
    ('jon', 'dunes,grace,pete,wingo', 'DSCF0854'),
    ('jon', 'dunes,jess,jimmy', 'DSCF0906'),
    ('jon', 'dunes,jess,jimmy', 'DSCF0920'),
    ('jon', 'dunes,slideshow', 'DSCF0846'),
    ('jon', 'eric', 'DSCF0898'),
    ('jon', 'eric,klayton', 'DSCF0909'),
    ('jon', 'eric,meta,nancy', 'DSCF0913'),
    ('jon', 'flowers', 'DSCF0952'),
    ('jon', 'friday', 'DSCF0807'),
    ('jon', 'friday', 'DSCF0808'),
    ('jon', 'friday,grace,leif,lily', 'DSCF0811'),
    ('jon', 'friday,jason,melissa,robin,susan', 'DSCF0800'),
    ('jon', 'friday,joff,robin,soren', 'DSCF0801'),
    ('jon', 'friday,leif,lily', 'DSCF0813'),
    ('jon', 'friday,leif,lily,not married', 'DSCF0814'),
    ('jon', 'friday,leif,lily,not married,silly', 'DSCF0804'),
    ('jon', 'glasses,hats,leif,slideshow', 'DSCF0885'),
    ('jon', 'glasses,jesse', 'DSCF0924'),
    ('jon', 'glasses,john,slideshow', 'DSCF0897'),
    ('jon', 'grace,hats,pete,slideshow,wingo', 'DSCF0888'),
    ('jon', 'grace,leif,setup', 'DSCF0838'),
    ('jon', 'grace,leif,setup,susan', 'DSCF0841'),
    ('jon', 'grace,pete,wingo', 'DSCF0843'),
    ('jon', 'grandparents', 'DSCF0939'),
    ('jon', 'hats,leif,lily,lunch', 'DSCF0883'),
    ('jon', 'jim,jimmy,john,leif,lily,wingo', 'DSCF0989'),
    ('jon', 'jimmy,josh,liz,lunch', 'DSCF0879'),
    ('jon', 'jon', 'DSCF0862'),
    ('jon', 'josh,leif', 'DSCF0921'),
    ('jon', 'leif', 'DSCF0889'),
    ('jon', 'leif,lily', 'DSCF0856'),
    ('jon', 'leif,pete,ring,wingo', 'DSCF0895'),
    ('jon', 'leif,setup', 'DSCF0831'),
    ('jon', 'leif,soren', 'DSCF0969'),
    ('jon', 'liza,meta,newton', 'DSCF0908'),
    ('jon', 'liza,meta,newton', 'DSCF0911'),
    ('jon', 'lunch', 'DSCF0866'),
    ('jon', 'lunch', 'DSCF0872'),
    ('jon', 'lunch,slideshow', 'DSCF0870'),
    ('jon', 'lunch,soren,susan', 'DSCF0886'),
    ('jon', 'meta,wingo', 'DSCF0932'),
    ('jon', 'millie', 'DSCF0821'),
    ('jon', 'paparazzi', 'DSCF0982'),
    ('jon', 'pete', 'DSCF0844'),
    ('jon', 'ring', 'DSCF0890'),
    ('jon', 'slideshow,amelia,andrea,jesse,john,leif,lily', 'DSCF0955'),
    ('jon', 'slideshow,amelia,dress,lily', 'DSCF0967'),
    ('jon', 'slideshow,amelia,jesse,leif,lily,soren', 'DSCF0964'),
    ('jon', 'slideshow,andrea,lily', 'DSCF0977'),
    ('jon', 'slideshow,bink,susan', 'DSCF0972'),
    ('jon', 'slideshow,dress,lily,toes', 'DSCF0975'),
    ('jon', 'slideshow,hannah,margo', 'DSCF0929'),
    ('jon', 'slideshow,jesse,leif,soren', 'DSCF0966'),
    ('jon', 'slideshow,john,lily', 'DSCF0979'),
    ('jon', 'slideshow,josh,lisa,peter', 'DSCF0992'),
    ('jon', 'slideshow,milling about', 'DSCF0928'),
    ('jon', 'susan,wingo', 'DSCF0845'),
    ('jon', 'wingo', 'DSCF0830'),
    ('jon', 'wingo', 'DSCF0834'),
    ('lisa', '', '2012-09-29 14.25.00'),
    ('lisa', 'amelia,ceremony', '2012-09-29 14.06.26'),
    ('lisa', 'amelia,ceremony,jesse', '2012-09-29 14.13.18'),
    ('lisa', 'amelia,jesse', '2012-09-29 14.13.12'),
    ('lisa', 'andrea', '2012-09-29 15.20.05'),
    ('lisa', 'andrea', '2012-09-29 15.20.09'),
    ('lisa', 'andrea', '2012-09-29 15.20.24'),
    ('lisa', 'andrea', '2012-09-29 15.24.56'),
    ('lisa', 'andrea', '2012-09-29 15.25.16'),
    ('lisa', 'andrea,hats,joanie,lisa,lunch', '2012-09-29 15.24.02'),
    ('lisa', 'andrea,hats,john,leif,lunch', '2012-09-29 16.12.21'),
    ('lisa', 'andrea,hats,lisa', '2012-09-29 15.25.47'),
    ('lisa', 'andrea,laura,valen', '2012-09-29 13.48.38'),
    ('lisa', 'andrea,lisa,lunch', '2012-09-29 15.24.49'),
    ('lisa', 'bink,carolyn,jim', '2012-09-29 13.46.29'),
    ('lisa', 'bink,carolyn,jim', '2012-09-29 13.46.40'),
    ('lisa', 'cass,kirsten,pete,tim', '2012-09-29 13.46.02'),
    ('lisa', 'ceremony', '2012-09-29 14.05.57'),
    ('lisa', 'ceremony', '2012-09-29 14.06.11'),
    ('lisa', 'ceremony', '2012-09-29 14.06.45'),
    ('lisa', 'ceremony', '2012-09-29 14.07.45'),
    ('lisa', 'ceremony,eric,nancy,peter,susan', '2012-09-29 14.04.32'),
    ('lisa', 'ceremony,laughs,leif,lily,peter', '2012-09-29 14.13.04'),
    ('lisa', 'ceremony,leif,lily,peter', '2012-09-29 14.11.30'),
    ('lisa', 'ceremony,leif,lily,peter', '2012-09-29 14.11.44'),
    ('lisa', 'ceremony,leif,lily,peter', '2012-09-29 14.21.55'),
    ('lisa', 'ceremony,leif,lily,peter', '2012-09-29 14.22.04'),
    ('lisa', 'ceremony,leif,lily,peter,ring', '2012-09-29 14.21.59'),
    ('lisa', 'ceremony,leif,lily,peter,secret', '2012-09-29 14.18.36'),
    ('lisa', 'ceremony,leif,lily,peter,secret', '2012-09-29 14.18.42'),
    ('lisa', 'ceremony,leif,lily,peter,soren', '2012-09-29 14.07.59'),
    ('lisa', 'ceremony,leif,lily,peter,soren', '2012-09-29 14.11.02'),
    ('lisa', 'ceremony,leif,lily,peter,soren', '2012-09-29 14.21.46'),
    ('lisa', 'ceremony,peter,slideshow', '2012-09-29 14.04.02'),
    ('lisa', 'ceremony,slideshow', '2012-09-29 14.21.27'),
    ('lisa', 'david,lisa', '2012-09-29 16.16.21'),
    ('lisa', 'david,lisa,lunch', '2012-09-29 14.39.45'),
    ('lisa', 'debbie,lily,lunch', '2012-09-29 16.32.16'),
    ('lisa', 'dunes', '2012-09-29 13.44.16'),
    ('lisa', 'dunes', '2012-09-29 13.47.26'),
    ('lisa', 'hannah,josh', '2012-09-29 14.26.56'),
    ('lisa', 'hannah,josh,margo', '2012-09-29 14.27.04'),
    ('lisa', 'hats,laughs,leif,lily,lunch,slideshow', '2012-09-29 14.57.49'),
    ('lisa', 'john,josh', '2012-09-29 13.43.33'),
    ('lisa', 'john,setup', '2012-09-29 13.48.11'),
    ('lisa', 'laughs,leif,lily,lunch', '2012-09-29 14.57.56'),
    ('lisa', 'laura,lisa', '2012-09-29 13.48.54'),
    ('lisa', 'leif', '2012-09-29 16.33.36'),
    ('lisa', 'leif,lily,slideshow,squinting,toast', '2012-09-29 14.27.10'),
    ('lisa', 'leif,slideshow', '2012-09-29 16.33.47'),
    ('lisa', 'lily', '2012-09-29 16.32.08'),
    ('lisa', 'lily', '2012-09-29 16.32.58'),
    ('lisa', 'lily', '2012-09-29 16.34.34'),
    ('lisa', 'lisa', '2012-09-29 16.16.12'),
    ('lisa', 'lisa,lunch', '2012-09-29 16.20.53'),
    ('lisa', 'lunch', '2012-09-29 14.35.08'),
    ('lisa', 'michael', '2012-09-29 16.32.27'),
    ('lisa', 'michael', '2012-09-29 16.32.35'),
    ('lisa', 'peter,tori', '2012-09-29 13.47.49'),
    ('lisa', 'soren,toast', '2012-09-29 16.13.31'),
    ('lisa', 'soren,toast', '2012-09-29 16.13.43'),
    ('lisa', 'tori', '2012-09-29 14.25.04'),
    ('liz', '', 'IMG_0847'),
    ('liz', '', 'IMG_0851'),
    ('liz', '', 'IMG_0914'),
    ('liz', 'amelia,ceremony,jesse,leif,lily,peter,soren', 'IMG_0870'),
    ('liz', 'amelia,friday,jess,lily', 'IMG_0839'),
    ('liz', 'andrea,eve', 'IMG_0924'),
    ('liz', 'andrea,eve', 'IMG_0925'),
    ('liz', 'andrew,eve', 'IMG_0864'),
    ('liz', 'andrew,eve,hats', 'IMG_0884'),
    ('liz', 'andrew,friday,jess,lily,susan', 'IMG_0840'),
    ('liz', 'andrew,glasses,hats,jess', 'IMG_0878'),
    ('liz', 'beach', 'IMG_0894'),
    ('liz', 'bink,joff,leif,setup', 'IMG_0853'),
    ('liz', 'ceremony,leif,lily,peter,soren', 'IMG_0867'),
    ('liz', 'ceremony,leif,lily,peter,soren', 'IMG_0868'),
    ('liz', 'dancing', 'IMG_0887'),
    ('liz', 'dancing,jesse,joanie,john,michael,valen', 'IMG_0915'),
    ('liz', 'dancing,leif,lily', 'IMG_0916'),
    ('liz', 'dancing,leif,lily', 'IMG_0917'),
    ('liz', 'dancing,leif,lily', 'IMG_0918'),
    ('liz', 'dancing,leif,lily', 'IMG_0919'),
    ('liz', 'dancing,leif,lily', 'IMG_0920'),
    ('liz', 'dancing,leif,lily', 'IMG_0921'),
    ('liz', 'david,eric,friday,jason,john,peter', 'IMG_0841'),
    ('liz', 'dessert', 'IMG_0931'),
    ('liz', 'dunes,jess,liz', 'IMG_0858'),
    ('liz', 'eve', 'IMG_0912'),
    ('liz', 'eve', 'IMG_0934'),
    ('liz', 'eve,hats,liz', 'IMG_0891'),
    ('liz', 'eve,lily', 'IMG_0922'),
    ('liz', 'eve,liz', 'IMG_0890'),
    ('liz', 'eve,ring', 'IMG_0872'),
    ('liz', 'flowers,setup', 'IMG_0848'),
    ('liz', 'flowers,setup', 'IMG_0849'),
    ('liz', 'friday', 'IMG_0860'),
    ('liz', 'friday,kiss,leif,lily', 'IMG_0842'),
    ('liz', 'jess,lily,liz,setup', 'IMG_0850'),
    ('liz', 'jess,lunch', 'IMG_0875'),
    ('liz', 'jess,setup', 'IMG_0852'),
    ('liz', 'jesse,setup', 'IMG_0844'),
    ('liz', 'leif,lily,peter,soren', 'IMG_0874'),
    ('liz', 'leif,toast', 'IMG_0886'),
    ('liz', 'ocean', 'IMG_0937'),
    ('liz', 'setup', 'IMG_0843'),
    ('liz', 'setup', 'IMG_0854'),
    ('liz', 'slideshow', 'IMG_0930'),
    ('liz', 'slideshow,flowers', 'IMG_0845'),
    ('liz', 'slideshow,jess,lily,liz', 'IMG_0883'),
    ('liz', 'slideshow,peter', 'IMG_0866'),
    ('liza', '', 'DSC08016'),
    ('liza', '', 'DSC08070'),
    ('liza', 'about to kiss,leif,lily', 'DSC08329'),
    ('liza', 'adriane,dress,leif,lily,slideshow', 'DSC08128'),
    ('liza', 'amanda,amy,josh,stephanie', 'DSC08076'),
    ('liza', 'amelia', 'DSC07995'),
    ('liza', 'amelia,andrea,jesse,john,leif,lily', 'DSC08407'),
    ('liza', 'amelia,ceremony,jesse,leif,lily,peter,slideshow,soren', 'DSC08003'),
    ('liza', 'amelia,ceremony,lily', 'DSC08015'),
    ('liza', 'amelia,dunes,janice,jesse,steve', 'DSC08204'),
    ('liza', 'amelia,hats,jesse,slideshow,toast', 'DSC08163'),
    ('liza', 'amelia,janice,jesse,steve', 'DSC08202'),
    ('liza', 'amelia,jesse', 'DSC08002'),
    ('liza', 'amelia,jesse', 'DSC08018'),
    ('liza', 'amelia,jesse,leif,lily,soren', 'DSC08424'),
    ('liza', 'amelia,jesse,leif,lily,valen', 'DSC08353'),
    ('liza', 'amelia,jesse,slideshow,toast', 'DSC08164'),
    ('liza', 'amelia,jesse,toast', 'DSC08167'),
    ('liza', 'amelia,leif,lily', 'DSC08360'),
    ('liza', 'amy,dancing,kirsten,lily', 'DSC08216'),
    ('liza', 'amy,dancing,lily,omg', 'DSC08214'),
    ('liza', 'amy,lily', 'DSC08213'),
    ('liza', 'andrea', 'DSC07993'),
    ('liza', 'andrea', 'DSC08001'),
    ('liza', 'andrea,bink,eric,john,leif,lily,nancy,susan', 'DSC08295'),
    ('liza', 'andrea,bink,hats,john,lisa,lunch', 'DSC08169'),
    ('liza', 'andrea,champagne', 'DSC08075'),
    ('liza', 'andrea,hats,john,leif,lily,slideshow', 'DSC08284'),
    ('liza', 'andrea,janice', 'DSC08133'),
    ('liza', 'andrea,john,leif,lily', 'DSC08285'),
    ('liza', 'andrea,lily', 'DSC08458'),
    ('liza', 'andrea,lily', 'DSC08459'),
    ('liza', 'andrea,lily,slideshow', 'DSC08463'),
    ('liza', 'andrea,peter,slideshow', 'DSC08282'),
    ('liza', 'andrea,susan', 'DSC08481'),
    ('liza', 'andrew,blue shirts,hannah,josh,millie,mormon', 'DSC08253'),
    ('liza', 'andrew,blue shirts,millie,mormon,wingo', 'DSC08236'),
    ('liza', 'beach', 'DSC08203'),
    ('liza', 'bee\'s knees', 'DSC08187'),
    ('liza', 'bee\'s knees,laughs,lily,nansamba', 'DSC08274'),
    ('liza', 'bee\'s knees,newton', 'DSC08184'),
    ('liza', 'bink,eric,nancy,slideshow,susan,toast', 'DSC08062'),
    ('liza', 'bink,eric,nancy,susan,toast', 'DSC08063'),
    ('liza', 'bink,leif,lily,susan', 'DSC08324'),
    ('liza', 'blue shirts,milling about', 'DSC08266'),
    ('liza', 'carlie,ring', 'DSC08008'),
    ('liza', 'ceremony', 'DSC08012'),
    ('liza', 'ceremony,david,jess,jim,joanie,liz,slideshow,tim', 'DSC08027'),
    ('liza', 'ceremony,glasses,hats,peter', 'DSC08014'),
    ('liza', 'ceremony,leif,lily,peter', 'DSC08000'),
    ('liza', 'ceremony,leif,lily,peter', 'DSC08010'),
    ('liza', 'ceremony,leif,lily,peter,ring', 'DSC08032'),
    ('liza', 'ceremony,leif,lily,peter,slideshow', 'DSC08030'),
    ('liza', 'ceremony,leif,lily,secret', 'DSC08022'),
    ('liza', 'ceremony,leif,lily,secret', 'DSC08024'),
    ('liza', 'ceremony,leif,lily,secret', 'DSC08025'),
    ('liza', 'ceremony,lily,peter', 'DSC07997'),
    ('liza', 'ceremony,lily,soren', 'DSC07996'),
    ('liza', 'champagne,dunes', 'DSC08068'),
    ('liza', 'champagne,eric,nancy', 'DSC08066'),
    ('liza', 'champagne,flowers', 'DSC08118'),
    ('liza', 'champagne,jimmy,laura', 'DSC08069'),
    ('liza', 'champagne,josh', 'DSC08059'),
    ('liza', 'champagne,leif,lily', 'DSC08077'),
    ('liza', 'champagne,leif,lily,toast', 'DSC08078'),
    ('liza', 'cuy,dancing,lily', 'DSC08224'),
    ('liza', 'dancing,leif,lily', 'DSC08241'),
    ('liza', 'dancing,leif,lily', 'DSC08252'),
    ('liza', 'dancing,leif,lily,slideshow', 'DSC08232'),
    ('liza', 'dancing,lisa', 'DSC08271'),
    ('liza', 'decor', 'DSC07953'),
    ('liza', 'decor', 'DSC08264'),
    ('liza', 'dessert', 'DSC08277'),
    ('liza', 'devin,jason,zane', 'DSC07976'),
    ('liza', 'dunes', 'DSC08116'),
    ('liza', 'dunes,slideshow', 'DSC08273'),
    ('liza', 'eric', 'DSC07983'),
    ('liza', 'eric,hats,leif,lily,nancy,slideshow', 'DSC08317'),
    ('liza', 'eric,ring', 'DSC08020'),
    ('liza', 'flags', 'DSC08220'),
    ('liza', 'flowers,leif,lily,slideshow', 'DSC08041'),
    ('liza', 'flowers,lunch', 'DSC08147'),
    ('liza', 'glasses,jesse,valen', 'DSC08097'),
    ('liza', 'grandparents', 'DSC07954'),
    ('liza', 'hannah,josh', 'DSC07982'),
    ('liza', 'hats,janice', 'DSC08111'),
    ('liza', 'hats,john,kiss,lily', 'DSC08471'),
    ('liza', 'hats,leif,silly', 'DSC08268'),
    ('liza', 'hats,lisa,peter', 'DSC08106'),
    ('liza', 'hats,milling about', 'DSC08146'),
    ('liza', 'janice,steve', 'DSC07959'),
    ('liza', 'janice,steve', 'DSC08067'),
    ('liza', 'janice,steve', 'DSC08103'),
    ('liza', 'jason,joff,robin,zane', 'DSC08217'),
    ('liza', 'jesse,john', 'DSC07994'),
    ('liza', 'jesse,lily', 'DSC08138'),
    ('liza', 'jesse,valen', 'DSC08351'),
    ('liza', 'john', 'DSC08280'),
    ('liza', 'john,leif', 'DSC08143'),
    ('liza', 'john,lily', 'DSC08467'),
    ('liza', 'john,toast', 'DSC08161'),
    ('liza', 'kirsten,wingo', 'DSC08207'),
    ('liza', 'kiss,liza,newton', 'DSC08092'),
    ('liza', 'leif', 'DSC08071'),
    ('liza', 'leif', 'DSC08136'),
    ('liza', 'leif,lily', 'DSC08151'),
    ('liza', 'leif,lily', 'DSC08335'),
    ('liza', 'leif,lily', 'DSC08341'),
    ('liza', 'leif,lily', 'DSC08370'),
    ('liza', 'leif,lily', 'DSC08393'),
    ('liza', 'leif,lily,lunch,slideshow', 'DSC08179'),
    ('liza', 'leif,lily,peter', 'DSC08308'),
    ('liza', 'leif,lily,slideshow', 'DSC08047'),
    ('liza', 'leif,newton', 'DSC08137'),
    ('liza', 'lily', 'DSC08478'),
    ('liza', 'liza,newton', 'DSC07970'),
    ('liza', 'louise', 'DSC07978'),
    ('liza', 'louise,nell,slideshow,thor', 'DSC08057'),
    ('liza', 'lunch,pgcc', 'DSC08156'),
    ('liza', 'lunch,slideshow', 'DSC08158'),
    ('liza', 'lunch,slideshow', 'DSC08159'),
    ('liza', 'lunch,toast', 'DSC08170'),
    ('liza', 'ring', 'DSC08398'),
    ('liza', 'slideshow,amelia,lily', 'DSC08436'),
    ('liza', 'slideshow,cass,homies,kirsten,pete,tim', 'DSC08305'),
    ('liza', 'slideshow,dancing,glasses,leif,lily', 'DSC08257'),
    ('liza', 'slideshow,dancing,laughs,lily,shay', 'DSC08225'),
    ('liza', 'slideshow,dessert', 'DSC08275'),
    ('liza', 'slideshow,dress,leif,lily', 'DSC08379'),
    ('liza', 'slideshow,dress,leif,lily', 'DSC08409'),
    ('liza', 'slideshow,dress,lily,toes', 'DSC08447'),
    ('liza', 'slideshow,jesse,leif,soren', 'DSC08425'),
    ('liza', 'slideshow,kiss,leif,lily', 'DSC08085'),
    ('liza', 'slideshow,kiss,leif,lily', 'DSC08313'),
    ('liza', 'slideshow,kiss,leif,lily', 'DSC08388'),
    ('liza', 'slideshow,leif,lily', 'DSC08337'),
    ('liza', 'slideshow,leif,lily', 'DSC08340'),
    ('liza', 'slideshow,leif,lily', 'DSC08342'),
    ('liza', 'slideshow,leif,lily', 'DSC08376'),
    ('liza', 'slideshow,leif,lily,toes', 'DSC08450'),
    ('liza', 'slideshow,leif,soren', 'DSC08442'),
    ('susan', 'adriane,amelia', 'IMG_6103'),
    ('susan', 'amy,andy,champagne,debbie,jimmy,lisa,max,nansamba', '100_1578'),
    ('susan', 'andrea,hats,john', 'IMG_6110'),
    ('susan', 'andrea,john', 'IMG_6079'),
    ('susan', 'bink,susan', 'IMG_6081'),
    ('susan', 'carolyn,jim', '100_1589'),
    ('susan', 'ceremony,dunes', 'IMG_6058'),
    ('susan', 'ceremony,leif,soren', 'IMG_6086'),
    ('susan', 'ceremony,leif,soren', 'IMG_6087'),
    ('susan', 'ceremony,leif,soren', 'IMG_6088'),
    ('susan', 'dancing', '100_1602'),
    ('susan', 'decor,joff,setup', 'IMG_6041'),
    ('susan', 'dunes,louise', 'IMG_6096'),
    ('susan', 'glasses,leif,silly,soren', 'IMG_6107'),
    ('susan', 'grandparents,slideshow', 'IMG_6046'),
    ('susan', 'jesse,nell,thor', 'IMG_6157'),
    ('susan', 'jesse,slideshow,valen', 'IMG_6154'),
    ('susan', 'leif,lily,silly', 'IMG_6108'),
    ('susan', 'louise,lunch,soren', 'IMG_6113'),
    ('susan', 'louise,susan', 'IMG_6035'),
    ('susan', 'nell,thor', 'IMG_6097'),
    ('susan', 'nell,thor', 'IMG_6158'),
    ('susan', 'robin', 'IMG_6078'),
    ('susan', 'slideshow,susan', 'IMG_6071'),
    ('tori', 'amelia,andrea,dunes,jesse,laura,sunset', 'IMG_7916'),
    ('tori', 'amelia,ceremony,jesse,lily,peter', 'IMG_7900'),
    ('tori', 'amelia,slideshow', 'IMG_7897'),
    ('tori', 'amy,flowers', 'IMG_7909'),
    ('tori', 'andrew,friday,mormon,pizza', 'IMG_7886'),
    ('tori', 'ceremony', 'IMG_7898'),
    ('tori', 'ceremony', 'IMG_7899'),
    ('tori', 'ceremony', 'IMG_7901'),
    ('tori', 'ceremony', 'IMG_7902'),
    ('tori', 'ceremony,dress,lily,peter', 'IMG_7891'),
    ('tori', 'ceremony,dress,lily,peter', 'IMG_7893'),
    ('tori', 'debbie,dunes', 'IMG_7911'),
    ('tori', 'demon cat,jupiter,the box', 'IMG_7880'),
    ('tori', 'dress,josh,lily', 'IMG_7905'),
    ('tori', 'dress,lily,lunch', 'IMG_7904'),
    ('tori', 'dunes', 'IMG_7888'),
    ('tori', 'dunes', 'IMG_7914'),
    ('tori', 'dunes', 'IMG_7915'),
    ('tori', 'dunes', 'IMG_7920'),
    ('tori', 'dunes,homies,sunset', 'IMG_7919'),
    ('tori', 'dunes,slideshow', 'IMG_7913'),
    ('tori', 'leif,lily', 'IMG_7903'),
    ('tori', 'leif,sunset,susan', 'IMG_7936'),
    ('tori', 'lily', 'IMG_7890'),
    ('tori', 'lily', 'IMG_7892'),
    ('tori', 'lily', 'IMG_7894'),
    ('tori', 'lily,pgcc', 'IMG_7906'),
    ('tori', 'lisa,peter', 'IMG_7931'),
    ('tori', 'lisa,peter', 'IMG_7934'),
    ('tori', 'ocean', 'IMG_7918'),
    ('tori', 'photos in jan\'s house', 'IMG_7908'),
    ('tori', 'slideshow,amelia,ceremony,jesse,leif,lily,peter,soren', 'IMG_7889'),
    ('tori', 'slideshow,ocean,sunset', 'IMG_7924'),
    ('tori', 'slideshow,sunset', 'IMG_7927'),
    ('tori', 'slideshow,sunset', 'IMG_7930'),
    ('valen', '', 'Ceremony 278'),
    ('valen', 'about to kiss,v', 'Ceremony 076'),
    ('valen', 'adriane,amelia,v', 'Ceremony 120'),
    ('valen', 'adriane,v', 'Ceremony 117'),
    ('valen', 'amanda,friday,josh,v', 'PreWedding 154'),
    ('valen', 'amelia,ceremony,jesse,leif,v', 'Ceremony 057'),
    ('valen', 'amelia,ceremony,jesse,lily,v', 'Ceremony 031'),
    ('valen', 'amelia,ceremony,jesse,lily,v', 'Ceremony 033'),
    ('valen', 'amelia,ceremony,jesse,lily,v', 'Ceremony 051'),
    ('valen', 'amelia,ceremony,leif,lily,v', 'Ceremony 087'),
    ('valen', 'amelia,dancing,jesse,joanie,kirsten,michael,v', 'Ceremony 158'),
    ('valen', 'amelia,dancing,jesse,v', 'Ceremony 161'),
    ('valen', 'amelia,decor,v', 'PreWedding 137'),
    ('valen', 'amelia,dressing room,jess,lily,v', 'WeddingDay 221'),
    ('valen', 'amelia,dressing room,jess,lily,v', 'WeddingDay 223'),
    ('valen', 'amelia,dressing room,jesse,lily,toes,v', 'WeddingDay 243'),
    ('valen', 'amelia,dressing room,lily,v,valen', 'WeddingDay 271'),
    ('valen', 'amelia,glasses,jesse', 'PreWedding 097'),
    ('valen', 'amelia,glasses,jesse,v', 'PreWedding 098'),
    ('valen', 'amelia,jesse,laughs,lily,v', 'Ceremony 032'),
    ('valen', 'amelia,jesse,leif,lily,soren,v', 'Ceremony 095'),
    ('valen', 'amelia,jesse,leif,lily,v', 'Ceremony 056'),
    ('valen', 'amelia,jesse,leif,lily,v', 'Ceremony 275'),
    ('valen', 'amelia,jesse,lily,v', 'Ceremony 015'),
    ('valen', 'amelia,jesse,lily,v', 'Ceremony 016'),
    ('valen', 'amelia,jesse,lily,v', 'Ceremony 017'),
    ('valen', 'amelia,laughs,lily,v', 'Ceremony 080'),
    ('valen', 'amelia,laughs,v', 'Ceremony 079'),
    ('valen', 'amelia,lily,v', 'Ceremony 295'),
    ('valen', 'amelia,shay,v', 'Ceremony 101'),
    ('valen', 'amelia,v', 'Ceremony 082'),
    ('valen', 'amy,andrew,eve,jess,liz,v', 'Ceremony 003'),
    ('valen', 'amy,cuy,lunch,shay,v', 'Ceremony 135'),
    ('valen', 'amy,dancing,john,v', 'Ceremony 188'),
    ('valen', 'amy,grace,john,v,wingo', 'Ceremony 121'),
    ('valen', 'amy,lunch,v', 'Ceremony 132'),
    ('valen', 'andrea,ceremony,v', 'Ceremony 026'),
    ('valen', 'andrea,cuy,v', 'Ceremony 002'),
    ('valen', 'andrea,dancing,john,leif,lily,v', 'Ceremony 177'),
    ('valen', 'andrea,dancing,john,leif,v', 'Ceremony 170'),
    ('valen', 'andrea,dancing,john,v', 'Ceremony 149'),
    ('valen', 'andrea,dancing,john,v', 'Ceremony 150'),
    ('valen', 'andrea,dancing,john,v', 'Ceremony 153'),
    ('valen', 'andrea,dressing room,lily,lisa,v', 'WeddingDay 269'),
    ('valen', 'andrea,dressing room,lily,v', 'WeddingDay 257'),
    ('valen', 'andrea,john,v', 'Ceremony 099'),
    ('valen', 'andrea,john,v', 'Ceremony 269'),
    ('valen', 'andrea,lily,v', 'Ceremony 301'),
    ('valen', 'andrea,v', 'Ceremony 315'),
    ('valen', 'andrew,david,dunes,v', 'Ceremony 204'),
    ('valen', 'andrew,eve,lily,v', 'Ceremony 190'),
    ('valen', 'andrew,glasses,pete,v,wingo', 'Ceremony 069'),
    ('valen', 'bink,carolyn,friday,jim,susan,v', 'PreWedding 162'),
    ('valen', 'bink,ceremony,eric,leif,nancy,susan,v', 'Ceremony 020'),
    ('valen', 'bobbie,friday,lily,peter,v', 'PreWedding 146'),
    ('valen', 'bobbie,nancy,v', 'Ceremony 274'),
    ('valen', 'carlie,ceremony,ring,v', 'Ceremony 034'),
    ('valen', 'ceremony,eric,nancy,susan,v', 'Ceremony 044'),
    ('valen', 'ceremony,jesse,john,v', 'Ceremony 027'),
    ('valen', 'ceremony,jesse,leif,lily,peter,v', 'Ceremony 042'),
    ('valen', 'ceremony,jesse,lily,v', 'Ceremony 037'),
    ('valen', 'ceremony,leif,lily,peter,v', 'Ceremony 039'),
    ('valen', 'ceremony,leif,peter,soren,v', 'Ceremony 022'),
    ('valen', 'ceremony,lily,v', 'Ceremony 030'),
    ('valen', 'ceremony,lily,v', 'Ceremony 047'),
    ('valen', 'ceremony,ring,v', 'Ceremony 085'),
    ('valen', 'ceremony,ring,v', 'Ceremony 092'),
    ('valen', 'ceremony,toes,v', 'Ceremony 054'),
    ('valen', 'ceremony,v', 'Ceremony 024'),
    ('valen', 'ceremony,v', 'Ceremony 038'),
    ('valen', 'ceremony,v', 'Ceremony 058'),
    ('valen', 'champagne,john,peter,soren,v', 'Ceremony 112'),
    ('valen', 'champagne,leif,lily,pgcc', 'Ceremony 110'),
    ('valen', 'conch,laura,v', 'Ceremony 314'),
    ('valen', 'cuy,david,shay,v', 'Ceremony 005'),
    ('valen', 'cuy,jason,milling about,shay,v', 'Ceremony 009'),
    ('valen', 'cuy,v', 'Ceremony 067'),
    ('valen', 'dancing,glasses,leif,lily,v', 'Ceremony 224'),
    ('valen', 'dancing,jesse,liz,v', 'Ceremony 186'),
    ('valen', 'dancing,john,lily,v', 'Ceremony 180'),
    ('valen', 'dancing,kirsten,leif,v', 'Ceremony 187'),
    ('valen', 'dancing,kiss,leif,lily', 'Ceremony 164'),
    ('valen', 'dancing,leif,lily,v', 'Ceremony 167'),
    ('valen', 'dancing,leif,soren,susan,v', 'Ceremony 251'),
    ('valen', 'dancing,lily,soren,v', 'Ceremony 226'),
    ('valen', 'dancing,lily,v', 'Ceremony 162'),
    ('valen', 'dancing,lily,v,wingo', 'Ceremony 229'),
    ('valen', 'dancing,soren,susan,v', 'Ceremony 249'),
    ('valen', 'dancing,v', 'Ceremony 141'),
    ('valen', 'david,kirsten,v', 'Ceremony 065'),
    ('valen', 'debbie,v', 'Ceremony 070'),
    ('valen', 'decor,joff,susan,v', 'PreWedding 125'),
    ('valen', 'decor,joff,susan,v', 'PreWedding 127'),
    ('valen', 'decor,joff,v', 'PreWedding 131'),
    ('valen', 'decor,john,v,wingo', 'Ceremony 119'),
    ('valen', 'decor,v', 'WeddingDay 214'),
    ('valen', 'devin,friday,v,zane', 'PreWedding 160'),
    ('valen', 'dress,dressing room,lily,toes,v', 'WeddingDay 264'),
    ('valen', 'dress,v', 'Ceremony 299'),
    ('valen', 'dressing room,jess,lily,v', 'WeddingDay 250'),
    ('valen', 'dunes,jess,jimmy,john,v', 'Ceremony 205'),
    ('valen', 'dunes,v', 'Ceremony 123'),
    ('valen', 'flags,klayton,v', 'Ceremony 236'),
    ('valen', 'flags,klayton,v', 'Ceremony 239'),
    ('valen', 'flags,v', 'Ceremony 316'),
    ('valen', 'flowers,lily,setup,v', 'WeddingDay 173'),
    ('valen', 'flowers,lily,setup,v', 'WeddingDay 175'),
    ('valen', 'friday,jess,v', 'PreWedding 144'),
    ('valen', 'friday,jesse,jimmy,louise,nancy,pizza,v', 'PreWedding 142'),
    ('valen', 'friday,john,v', 'PreWedding 158'),
    ('valen', 'friday,louise,millie,v', 'PreWedding 169'),
    ('valen', 'glasses,lisa,v,wingo', 'Ceremony 068'),
    ('valen', 'janice,jesse,lisa,steve,v', 'Ceremony 210'),
    ('valen', 'janice,lily,steve,v', 'Ceremony 124'),
    ('valen', 'janice,liza,lunch,nansamba,v', 'Ceremony 131'),
    ('valen', 'jesse,setup,v', 'WeddingDay 171'),
    ('valen', 'jesse,setup,v', 'WeddingDay 189'),
    ('valen', 'jesse,v', 'Ceremony 062'),
    ('valen', 'jesse,v', 'Ceremony 074'),
    ('valen', 'jesse,v,valen', 'Ceremony 306'),
    ('valen', 'joff,setup,susan,v', 'WeddingDay 178'),
    ('valen', 'john,lily,v', 'Ceremony 303'),
    ('valen', 'john,lily,v', 'Ceremony 305'),
    ('valen', 'john,peter,soren,v', 'Ceremony 098'),
    ('valen', 'john,peter,soren,v', 'Ceremony 100'),
    ('valen', 'john,setup,v', 'PreWedding 026'),
    ('valen', 'john,soren,v', 'Ceremony 104'),
    ('valen', 'john,steve,v', 'Ceremony 118'),
    ('valen', 'josh,leif,v', 'Ceremony 202'),
    ('valen', 'kiss,leif,lily,v', 'Ceremony 285'),
    ('valen', 'laura,v', 'Ceremony 007'),
    ('valen', 'leif,lily,v', 'Ceremony 174'),
    ('valen', 'leif,lily,v', 'Ceremony 272'),
    ('valen', 'leif,lily,v', 'Ceremony 282'),
    ('valen', 'leif,ring,v', 'Ceremony 142'),
    ('valen', 'leif,soren,v', 'Ceremony 011'),
    ('valen', 'leif,soren,v', 'Ceremony 014'),
    ('valen', 'leif,soren,v', 'Ceremony 018'),
    ('valen', 'leif,v', 'Ceremony 064'),
    ('valen', 'leif,v', 'Ceremony 097'),
    ('valen', 'lily,liza,v', 'Ceremony 297'),
    ('valen', 'lily,lunch,margo,v', 'Ceremony 134'),
    ('valen', 'lily,lunch,v', 'Ceremony 130'),
    ('valen', 'lily,ring,v', 'Ceremony 088'),
    ('valen', 'lily,stephanie,v', 'Ceremony 125'),
    ('valen', 'lily,v', 'Ceremony 013'),
    ('valen', 'lily,v', 'Ceremony 060'),
    ('valen', 'lily,v', 'Ceremony 072'),
    ('valen', 'lily,v', 'Ceremony 073'),
    ('valen', 'lily,v', 'Ceremony 075'),
    ('valen', 'lily,v', 'Ceremony 317'),
    ('valen', 'lily,v', 'WeddingDay 247'),
    ('valen', 'lisa,peter,v', 'Ceremony 115'),
    ('valen', 'lunch,v', 'Ceremony 140'),
    ('valen', 'peter,slideshow,v', 'Ceremony 310'),
    ('valen', 'peter,v', 'Ceremony 061'),
    ('valen', 'setup,v', 'WeddingDay 170'),
    ('valen', 'setup,v', 'WeddingDay 184'),
    ('valen', 'setup,v', 'WeddingDay 186'),
    ('valen', 'shay,v', 'Ceremony 133'),
    ('valen', 'soren,v', 'Ceremony 063'),
    ('valen', 'tim,v', 'Ceremony 066'),
    ('valen', 'toast,v', 'Ceremony 114'),
    ('wingo', 'beach,grace,millie', 'DSCN1836'),
    ('wingo', 'ceremony', 'DSCN1807'),
    ('wingo', 'corinne,dunes', 'DSCN1835'),
    ('wingo', 'dunes,silly,wingo', 'DSCN1829'),
    ('wingo', 'jon,sunset', 'DSCN1848'),
    ('wingo', 'ocean', 'DSCN1838'),
    ('wingo', 'ocean', 'DSCN1842'),
    ('wingo', 'slideshow,ocean', 'DSCN1837'),
    ('wingo', 'slideshow,tim', 'DSCN1820'),
    ]

def tags_for(path):
    tags = []
    user = ''
    basename = os.path.basename(path).split('.')[0]
    dirname = os.path.basename(os.path.dirname(path))
    if dirname.startswith('from-'):
        user = dirname.replace('from-', '')
        tags.append('201209-wedding')
    if dirname == '201209-wedding':
        user, basename = basename.split('-', 1)
    tags.append('by:{}'.format(user))
    for u, ts, name in DB:
        if u.lower() == user.lower() and name.lower() == basename.lower():
            tags.append('on:elem')
            tags.extend(ts.split(','))
            break
    return tags
